
EnableExplicit

;Nautilus Engine Demo
;Version: 1.00

;Tutorial 1
;Window creation

XIncludeFile "nautilus.pbi"

Procedure.i Main()
  
  ;Imported Functions:
  
;   Import "..."
;     nautilusCreate.i(hWnd.i,Width.i,Height.i,FPS.i)                                             ;<- create the Engine Object/Interface by using an already existing Window
;     nautilusWindow.i(Title.s,WindowWidth.i,WindowHeight.i,WindowType.i,Width.i,Height.i,FPS.i)  ;<- create a Window and the Engine Object/Interface
  
      ;The Engine FPS can be set freely (30 -> 60)
      ;Frame Per Seconds dictates the time between Frames
  
      ;30 FPS ~ 33 ms
      ;60 FPS ~ 16 ms
  
;     nautilusWindowHandle.i(*Engine)                                                             ;<- this just returns the Window handle
;     nautilusWindowTitle.i(*Engine,Title.s,Append.b = #False)                                    ;<- change the Window title or append text to it
;     nautilusWindowIcon(*Engine,*Icon)                                                           ;<- a Icon can be set (*Icon -> a pointer to an image in memory)
;     nautilusWindowExit.i()                                                                      ;<- check if the Window was closed
;     nautilusWindowClose.i(*Engine)                                                              ;<- close down the Window!
;     nautilusVersion.i()                                                                         ;<- get the Engine Version (compare this to #NE_VERSION)
;   EndImport
 
  ;there can only be 1 Engine Object/Interface at the same time!
  ;press [ESCAPE] to close the Windows
  
  Protected *engine.NE_ENGINE;<- Define the Engine Object/Interface
  Protected window_event.i
  
  ;there are 3 different WindowTypes:
  
  ;#NE_WINDOW_NORMAL
  ;#NE_WINDOW_SIZEABLE
  ;#NE_WINDOW_BLANK

  *engine = nautilusWindow("Tutorial 1: Normal Window!",800,600,#NE_WINDOW_NORMAL,320,200,60);<- create the Engine Object/Interface
  If *engine                                        ;<- check if it was created
    Repeat
      If *engine\InputKey(#VK_ESCAPE):Break:EndIf   ;<- of the [ESCAPE] key is pressed end the loop
      If *engine\RenderBegin():*engine\RenderEnd():EndIf
    Until nautilusWindowExit()                      ;<- wait for the Window to Exit
    nautilusWindowClose(*engine)                    ;<- close down the Window and Engine (dont call *engine\Release())
  EndIf 
  
  ;--------------------------------------
  
  *engine = nautilusWindow("Tutorial 1: Sizeable Window!",800,600,#NE_WINDOW_SIZEABLE,320,200,60)
  If *engine
    Repeat
      If *engine\InputKey(#VK_ESCAPE):Break:EndIf
      If *engine\RenderBegin():*engine\RenderEnd():EndIf
    Until nautilusWindowExit()
    nautilusWindowClose(*engine)
  EndIf
  ;--------------------------------------
  
  ;A Blank Window (borderless) Window thats always on top!
  *engine = nautilusWindow("Tutorial 1: Blank Window!",800,600,#NE_WINDOW_BLANK,320,200,60)
  If *engine
    Repeat
      If *engine\InputKey(#VK_ESCAPE):Break:EndIf
      If *engine\RenderBegin():*engine\RenderEnd():EndIf
    Until nautilusWindowExit()
    nautilusWindowClose(*engine)
  EndIf 
  
  ;--------------------------------------
  
  ;If WindowWidth and WindowHeight are #Null (and the WindowType is #NE_WINDOW_BLANK) the Window becomes 'FullScreen'!
  *engine = nautilusWindow("Tutorial 1: Blank Window!",0,0,#NE_WINDOW_BLANK,320,200,60)
  If *engine
    Repeat
      If *engine\InputKey(#VK_ESCAPE):Break:EndIf
      If *engine\RenderBegin():*engine\RenderEnd():EndIf
    Until nautilusWindowExit()
    nautilusWindowClose(*engine)
  EndIf
  
  ;--------------------------------------
  
  ;Custom Window + render to Gadget
  If OpenWindow(0,#Null,#Null,800,600,"Tutorial 1: Custom Window",#PB_Window_SystemMenu|#PB_Window_ScreenCentered)
    If CanvasGadget(1,10,10,400,400,#PB_Canvas_Keyboard)
      *engine = nautilusCreate(GadgetID(1),100,100,60);<- lets render to a canvas and not the window
      If *engine
        Repeat
          Repeat
            window_event = WindowEvent()
            Select window_event
              Case #PB_Event_CloseWindow
                Break 2
              Case #PB_Event_Gadget
                If EventType() = #PB_EventType_KeyDown;check for keys here (needed because the engine is not tied to the window)
                  Break 2
                EndIf 
            EndSelect
          Until window_event = #Null
          If *engine\RenderBegin():*engine\RenderEnd():EndIf
          SetActiveGadget(1);lazy code to make sure the canvas is active!
        ForEver
        *engine\Release();<- now we need to call this as we cant use nautilusWindowClose()!
      EndIf 
    EndIf
    CloseWindow(0)
  EndIf 
  ProcedureReturn #Null
EndProcedure

Main()

End

; IDE Options = PureBasic 5.62 (Windows - x86)
; CursorPosition = 49
; FirstLine = 87
; Folding = -
; EnableXP